import 'dart:async';

import 'package:flutter/services.dart';
import 'package:haptics/models/haptic_level.dart';

class HapticsMobile {
  static const MethodChannel _channel = MethodChannel('vibrate');
  static const Duration defaultVibrationDuration = Duration(milliseconds: 500);

  /// Vibrate for 500ms on Android, and for the default time on iOS (about 500ms as well)
  static Future vibrate() => _channel.invokeMethod(
        'vibrate',
        {'duration': defaultVibrationDuration.inMilliseconds},
      );

  /// Whether the device can actually vibrate or not
  static Future<bool> get canVibrate async {
    final bool isOn = await _channel.invokeMethod('canVibrate');
    return isOn;
  }

  static void feedback(HapticLevel type) {
    switch (type) {
      case HapticLevel.impact:
        _channel.invokeMethod('impact');
        break;
      case HapticLevel.error:
        _channel.invokeMethod('error');
        break;
      case HapticLevel.success:
        _channel.invokeMethod('success');
        break;
      case HapticLevel.warning:
        _channel.invokeMethod('warning');
        break;
      case HapticLevel.selection:
        _channel.invokeMethod('selection');
        break;
      case HapticLevel.heavy:
        _channel.invokeMethod('heavy');
        break;
      case HapticLevel.medium:
        _channel.invokeMethod('medium');
        break;
      case HapticLevel.light:
        _channel.invokeMethod('light');
        break;
      default:
    }
  }

  static Future vHapticLevelibrateWithPauses(Iterable<Duration> pauses) async {
    for (final Duration d in pauses) {
      await vibrate();
      //Because the native vibration is not awaited, we need to wait for
      //the vibration to end before launching another one
      await Future.delayed(defaultVibrationDuration);
      await Future.delayed(d);
    }
    await vibrate();
  }
}
